@@ -1,46 +1,40 @@
 import logging
-from datetime import timedelta
+from datetime import datetime, timedelta, timezone
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
+from arrow import Arrow
 from pandas import DataFrame
+from numpy import int64
 from tabulate import tabulate
 
+from freqtrade.constants import DATETIME_PRINT_FORMAT, LAST_BT_RESULT_FN
+from freqtrade.data.btanalysis import calculate_max_drawdown, calculate_market_change
 from freqtrade.misc import file_dump_json
 
 logger = logging.getLogger(__name__)
 
 
-def store_backtest_result(recordfilename: Path, all_results: Dict[str, DataFrame]) -> None:
+def store_backtest_stats(recordfilename: Path, stats: Dict[str, DataFrame]) -> None:
     """
-    Stores backtest results to file (one file per strategy)
-    :param recordfilename: Destination filename
-    :param all_results: Dict of Dataframes, one results dataframe per strategy
+    Stores backtest results
+    :param recordfilename: Path object, which can either be a filename or a directory.
+        Filenames will be appended with a timestamp right before the suffix
+        while for diectories, <directory>/backtest-result-<datetime>.json will be used as filename
+    :param stats: Dataframe containing the backtesting statistics
     """
-    for strategy, results in all_results.items():
-        records = backtest_result_to_list(results)
+    if recordfilename.is_dir():
+        filename = (recordfilename /
+                    f'backtest-result-{datetime.now().strftime("%Y-%m-%d_%H-%M-%S")}.json')
+    else:
+        filename = Path.joinpath(
+            recordfilename.parent,
+            f'{recordfilename.stem}-{datetime.now().strftime("%Y-%m-%d_%H-%M-%S")}'
+            ).with_suffix(recordfilename.suffix)
+    file_dump_json(filename, stats)
 
-        if records:
-            filename = recordfilename
-            if len(all_results) > 1:
-                # Inject strategy to filename
-                filename = Path.joinpath(
-                    recordfilename.parent,
-                    f'{recordfilename.stem}-{strategy}').with_suffix(recordfilename.suffix)
-            logger.info(f'Dumping backtest results to {filename}')
-            file_dump_json(filename, records)
-
-
-def backtest_result_to_list(results: DataFrame) -> List[List]:
-    """
-    Converts a list of Backtest-results to list
-    :param results: Dataframe containing results for one strategy
-    :return: List of Lists containing the trades
-    """
-    return [[t.pair, t.profit_percent, t.open_time.timestamp(),
-             t.close_time.timestamp(), t.open_index - 1, t.trade_duration,
-             t.open_rate, t.close_rate, t.open_at_end, t.sell_reason.value]
-            for index, t in results.iterrows()]
+    latest_filename = Path.joinpath(filename.parent, LAST_BT_RESULT_FN)
+    file_dump_json(latest_filename, {'latest_backtest': str(filename.name)})
 
 
 def _get_line_floatfmt() -> List[str]:
@@ -66,11 +60,12 @@ def _generate_result_line(result: DataFrame, max_open_trades: int, first_column:
     return {
         'key': first_column,
         'trades': len(result),
-        'profit_mean': result['profit_percent'].mean(),
-        'profit_mean_pct': result['profit_percent'].mean() * 100.0,
+        'profit_mean': result['profit_percent'].mean() if len(result) > 0 else 0.0,
+        'profit_mean_pct': result['profit_percent'].mean() * 100.0 if len(result) > 0 else 0.0,
         'profit_sum': result['profit_percent'].sum(),
         'profit_sum_pct': result['profit_percent'].sum() * 100.0,
         'profit_total_abs': result['profit_abs'].sum(),
+        'profit_total': result['profit_percent'].sum() / max_open_trades,
         'profit_total_pct': result['profit_percent'].sum() * 100.0 / max_open_trades,
         'duration_avg': str(timedelta(
                             minutes=round(result['trade_duration'].mean()))
@@ -127,7 +122,7 @@ def generate_sell_reason_stats(max_open_trades: int, results: DataFrame) -> List
 
         profit_mean = result['profit_percent'].mean()
         profit_sum = result["profit_percent"].sum()
-        profit_percent_tot = round(result['profit_percent'].sum() * 100.0 / max_open_trades, 2)
+        profit_percent_tot = result['profit_percent'].sum() / max_open_trades
 
         tabular_data.append(
             {
@@ -141,25 +136,25 @@ def generate_sell_reason_stats(max_open_trades: int, results: DataFrame) -> List
                 'profit_sum': profit_sum,
                 'profit_sum_pct': round(profit_sum * 100, 2),
                 'profit_total_abs': result['profit_abs'].sum(),
-                'profit_pct_total': profit_percent_tot,
+                'profit_total': profit_percent_tot,
+                'profit_total_pct': round(profit_percent_tot * 100, 2),
             }
         )
     return tabular_data
 
 
-def generate_strategy_metrics(stake_currency: str, max_open_trades: int,
-                              all_results: Dict) -> List[Dict]:
+def generate_strategy_metrics(all_results: Dict) -> List[Dict]:
     """
     Generate summary per strategy
-    :param stake_currency: stake-currency - used to correctly name headers
-    :param max_open_trades: Maximum allowed open trades used for backtest
     :param all_results: Dict of <Strategyname: BacktestResult> containing results for all strategies
     :return: List of Dicts containing the metrics per Strategy
     """
 
     tabular_data = []
     for strategy, results in all_results.items():
-        tabular_data.append(_generate_result_line(results, max_open_trades, strategy))
+        tabular_data.append(_generate_result_line(
+            results['results'], results['config']['max_open_trades'], strategy)
+            )
     return tabular_data
 
 
@@ -189,19 +184,63 @@ def generate_edge_table(results: dict) -> str:
                     floatfmt=floatfmt, tablefmt="orgtbl", stralign="right")  # type: ignore
 
 
-def generate_backtest_stats(config: Dict, btdata: Dict[str, DataFrame],
-                            all_results: Dict[str, DataFrame]) -> Dict[str, Any]:
+def generate_daily_stats(results: DataFrame) -> Dict[str, Any]:
+    if len(results) == 0:
+        return {
+            'backtest_best_day': 0,
+            'backtest_worst_day': 0,
+            'winning_days': 0,
+            'draw_days': 0,
+            'losing_days': 0,
+            'winner_holding_avg': timedelta(),
+            'loser_holding_avg': timedelta(),
+        }
+    daily_profit = results.resample('1d', on='close_date')['profit_percent'].sum()
+    worst = min(daily_profit)
+    best = max(daily_profit)
+    winning_days = sum(daily_profit > 0)
+    draw_days = sum(daily_profit == 0)
+    losing_days = sum(daily_profit < 0)
+
+    winning_trades = results.loc[results['profit_percent'] > 0]
+    losing_trades = results.loc[results['profit_percent'] < 0]
+
+    return {
+        'backtest_best_day': best,
+        'backtest_worst_day': worst,
+        'winning_days': winning_days,
+        'draw_days': draw_days,
+        'losing_days': losing_days,
+        'winner_holding_avg': (timedelta(minutes=round(winning_trades['trade_duration'].mean()))
+                               if not winning_trades.empty else timedelta()),
+        'loser_holding_avg': (timedelta(minutes=round(losing_trades['trade_duration'].mean()))
+                              if not losing_trades.empty else timedelta()),
+    }
+
+
+def generate_backtest_stats(btdata: Dict[str, DataFrame],
+                            all_results: Dict[str, Dict[str, Union[DataFrame, Dict]]],
+                            min_date: Arrow, max_date: Arrow
+                            ) -> Dict[str, Any]:
     """
-    :param config: Configuration object used for backtest
     :param btdata: Backtest data
-    :param all_results: backtest result - dictionary with { Strategy: results}.
+    :param all_results: backtest result - dictionary in the form:
+                     { Strategy: {'results: results, 'config: config}}.
+    :param min_date: Backtest start date
+    :param max_date: Backtest end date
     :return:
     Dictionary containing results per strategy and a stratgy summary.
     """
-    stake_currency = config['stake_currency']
-    max_open_trades = config['max_open_trades']
     result: Dict[str, Any] = {'strategy': {}}
-    for strategy, results in all_results.items():
+    market_change = calculate_market_change(btdata, 'close')
+
+    for strategy, content in all_results.items():
+        results: Dict[str, DataFrame] = content['results']
+        if not isinstance(results, DataFrame):
+            continue
+        config = content['config']
+        max_open_trades = config['max_open_trades']
+        stake_currency = config['stake_currency']
 
         pair_results = generate_pair_metrics(btdata, stake_currency=stake_currency,
                                              max_open_trades=max_open_trades,
@@ -212,17 +251,69 @@ def generate_backtest_stats(config: Dict, btdata: Dict[str, DataFrame],
                                                   max_open_trades=max_open_trades,
                                                   results=results.loc[results['open_at_end']],
                                                   skip_nan=True)
+        daily_stats = generate_daily_stats(results)
+
+        results['open_timestamp'] = results['open_date'].astype(int64) // 1e6
+        results['close_timestamp'] = results['close_date'].astype(int64) // 1e6
+
+        backtest_days = (max_date - min_date).days
         strat_stats = {
-            'trades': backtest_result_to_list(results),
+            'trades': results.to_dict(orient='records'),
             'results_per_pair': pair_results,
             'sell_reason_summary': sell_reason_stats,
             'left_open_trades': left_open_results,
-            }
+            'total_trades': len(results),
+            'profit_mean': results['profit_percent'].mean() if len(results) > 0 else 0,
+            'profit_total': results['profit_percent'].sum(),
+            'profit_total_abs': results['profit_abs'].sum(),
+            'backtest_start': min_date.datetime,
+            'backtest_start_ts': min_date.timestamp * 1000,
+            'backtest_end': max_date.datetime,
+            'backtest_end_ts': max_date.timestamp * 1000,
+            'backtest_days': backtest_days,
+
+            'trades_per_day': round(len(results) / backtest_days, 2) if backtest_days > 0 else 0,
+            'market_change': market_change,
+            'pairlist': list(btdata.keys()),
+            'stake_amount': config['stake_amount'],
+            'stake_currency': config['stake_currency'],
+            'max_open_trades': (config['max_open_trades']
+                                if config['max_open_trades'] != float('inf') else -1),
+            'timeframe': config['timeframe'],
+            # Parameters relevant for backtesting
+            'stoploss': config['stoploss'],
+            'trailing_stop': config.get('trailing_stop', False),
+            'trailing_stop_positive': config.get('trailing_stop_positive'),
+            'trailing_stop_positive_offset': config.get('trailing_stop_positive_offset', 0.0),
+            'trailing_only_offset_is_reached': config.get('trailing_only_offset_is_reached', False),
+            'minimal_roi': config['minimal_roi'],
+            'use_sell_signal': config['ask_strategy']['use_sell_signal'],
+            'sell_profit_only': config['ask_strategy']['sell_profit_only'],
+            'ignore_roi_if_buy_signal': config['ask_strategy']['ignore_roi_if_buy_signal'],
+            **daily_stats,
+        }
         result['strategy'][strategy] = strat_stats
 
-    strategy_results = generate_strategy_metrics(stake_currency=stake_currency,
-                                                 max_open_trades=max_open_trades,
-                                                 all_results=all_results)
+        try:
+            max_drawdown, drawdown_start, drawdown_end = calculate_max_drawdown(
+                results, value_col='profit_percent')
+            strat_stats.update({
+                'max_drawdown': max_drawdown,
+                'drawdown_start': drawdown_start,
+                'drawdown_start_ts': drawdown_start.timestamp() * 1000,
+                'drawdown_end': drawdown_end,
+                'drawdown_end_ts': drawdown_end.timestamp() * 1000,
+            })
+        except ValueError:
+            strat_stats.update({
+                'max_drawdown': 0.0,
+                'drawdown_start': datetime(1970, 1, 1, tzinfo=timezone.utc),
+                'drawdown_start_ts': 0,
+                'drawdown_end': datetime(1970, 1, 1, tzinfo=timezone.utc),
+                'drawdown_end_ts': 0,
+            })
+
+    strategy_results = generate_strategy_metrics(all_results=all_results)
 
     result['strategy_comparison'] = strategy_results
 
@@ -273,7 +364,7 @@ def text_table_sell_reason(sell_reason_stats: List[Dict[str, Any]], stake_curren
 
     output = [[
         t['sell_reason'], t['trades'], t['wins'], t['draws'], t['losses'],
-        t['profit_mean_pct'], t['profit_sum_pct'], t['profit_total_abs'], t['profit_pct_total'],
+        t['profit_mean_pct'], t['profit_sum_pct'], t['profit_total_abs'], t['profit_total_pct'],
     ] for t in sell_reason_stats]
     return tabulate(output, headers=headers, tablefmt="orgtbl", stralign="right")
 
@@ -298,6 +389,35 @@ def text_table_strategy(strategy_results, stake_currency: str) -> str:
                     floatfmt=floatfmt, tablefmt="orgtbl", stralign="right")
 
 
+def text_table_add_metrics(strat_results: Dict) -> str:
+    if len(strat_results['trades']) > 0:
+        min_trade = min(strat_results['trades'], key=lambda x: x['open_date'])
+        metrics = [
+            ('Backtesting from', strat_results['backtest_start'].strftime(DATETIME_PRINT_FORMAT)),
+            ('Backtesting to', strat_results['backtest_end'].strftime(DATETIME_PRINT_FORMAT)),
+            ('Total trades', strat_results['total_trades']),
+            ('First trade', min_trade['open_date'].strftime(DATETIME_PRINT_FORMAT)),
+            ('First trade Pair', min_trade['pair']),
+            ('Total Profit %', f"{round(strat_results['profit_total'] * 100, 2)}%"),
+            ('Trades per day', strat_results['trades_per_day']),
+            ('Best day', f"{round(strat_results['backtest_best_day'] * 100, 2)}%"),
+            ('Worst day', f"{round(strat_results['backtest_worst_day'] * 100, 2)}%"),
+            ('Days win/draw/lose', f"{strat_results['winning_days']} / "
+                f"{strat_results['draw_days']} / {strat_results['losing_days']}"),
+            ('Avg. Duration Winners', f"{strat_results['winner_holding_avg']}"),
+            ('Avg. Duration Loser', f"{strat_results['loser_holding_avg']}"),
+            ('', ''),  # Empty line to improve readability
+            ('Max Drawdown', f"{round(strat_results['max_drawdown'] * 100, 2)}%"),
+            ('Drawdown Start', strat_results['drawdown_start'].strftime(DATETIME_PRINT_FORMAT)),
+            ('Drawdown End', strat_results['drawdown_end'].strftime(DATETIME_PRINT_FORMAT)),
+            ('Market change', f"{round(strat_results['market_change'] * 100, 2)}%"),
+        ]
+
+        return tabulate(metrics, headers=["Metric", "Value"], tablefmt="orgtbl")
+    else:
+        return ''
+
+
 def show_backtest_results(config: Dict, backtest_stats: Dict):
     stake_currency = config['stake_currency']
 
@@ -312,15 +432,21 @@ def show_backtest_results(config: Dict, backtest_stats: Dict):
 
         table = text_table_sell_reason(sell_reason_stats=results['sell_reason_summary'],
                                        stake_currency=stake_currency)
-        if isinstance(table, str):
+        if isinstance(table, str) and len(table) > 0:
             print(' SELL REASON STATS '.center(len(table.splitlines()[0]), '='))
         print(table)
 
         table = text_table_bt_results(results['left_open_trades'], stake_currency=stake_currency)
-        if isinstance(table, str):
+        if isinstance(table, str) and len(table) > 0:
             print(' LEFT OPEN TRADES REPORT '.center(len(table.splitlines()[0]), '='))
         print(table)
-        if isinstance(table, str):
+
+        table = text_table_add_metrics(results)
+        if isinstance(table, str) and len(table) > 0:
+            print(' SUMMARY METRICS '.center(len(table.splitlines()[0]), '='))
+        print(table)
+
+        if isinstance(table, str) and len(table) > 0:
             print('=' * len(table.splitlines()[0]))
         print()
 
